Rename the PolicyManager to UpdateManager.

This change renames the PolicyManager class, directory, tests, etc,
to avoid confusion with libpolicy and its classes.

BUG=chromium:373551
TEST=emerged on link.
CQ-DEPEND=CL:I43081673c7ba409f02273197da7915537bde39c6

Change-Id: Iffa76caa3b95ecbbdba87ab01006d1d8ce35a27f
Reviewed-on: https://chromium-review.googlesource.com/201876
Tested-by: Alex Deymo <deymo@chromium.org>
Reviewed-by: David Zeuthen <zeuthen@chromium.org>
Commit-Queue: Alex Deymo <deymo@chromium.org>
diff --git a/real_system_state.cc b/real_system_state.cc
index 10b66f3..4886b91 100644
--- a/real_system_state.cc
+++ b/real_system_state.cc
@@ -7,7 +7,7 @@
 #include <base/file_util.h>
 
 #include "update_engine/constants.h"
-#include "update_engine/policy_manager/state_factory.h"
+#include "update_engine/update_manager/state_factory.h"
 #include "update_engine/utils.h"
 
 namespace chromeos_update_engine {
@@ -43,16 +43,16 @@
   p2p_manager_.reset(P2PManager::Construct(NULL, &prefs_, "cros_au",
                                            kMaxP2PFilesToKeep));
 
-  // Initialize the PolicyManager using the default State Factory.
-  chromeos_policy_manager::State* pm_state =
-      chromeos_policy_manager::DefaultStateFactory(
+  // Initialize the Update Manager using the default state factory.
+  chromeos_update_manager::State* um_state =
+      chromeos_update_manager::DefaultStateFactory(
           &policy_provider_, &dbus_, this);
-  if (!pm_state) {
-    LOG(ERROR) << "Failed to initialize the policy manager.";
+  if (!um_state) {
+    LOG(ERROR) << "Failed to initialize the Update Manager.";
     return false;
   }
-  policy_manager_.reset(
-      new chromeos_policy_manager::PolicyManager(&clock_, pm_state));
+  update_manager_.reset(
+      new chromeos_update_manager::UpdateManager(&clock_, um_state));
 
   if (!payload_state_.Initialize(this)) {
     LOG(ERROR) << "Failed to initialize the payload state object.";